"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.HabitController = void 0;
const habit_record_1 = require("../records/habit-record");
class HabitController {
    static listHabits(req, res) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            const { user: userId } = req.query;
            const habits = yield habit_record_1.HabitRecord.listAllByUserId(userId);
            if (habits[0] && ((_a = habits[0]) === null || _a === void 0 ? void 0 : _a.userId) !== req.userId) {
                return res.sendStatus(401);
            }
            res.json(habits);
        });
    }
    static getOne(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            const { habitId } = req.params;
            const habit = yield habit_record_1.HabitRecord.getOneById(habitId);
            if (habit && habit.userId !== req.userId) {
                return res.sendStatus(401);
            }
            res.json(habit);
        });
    }
    static add(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            const obj = req.body;
            const firstStatDate = new Date(new Date(obj.lastStatUpdateDate).setHours(0, 0, 0, 0) - 39 * 24 * 60 * 60 * 1000);
            const lastStatUpdateDate = new Date(new Date(obj.lastStatUpdateDate).setHours(0, 0, 0, 0));
            const currentlyAddedHabitsNo = yield habit_record_1.HabitRecord.getHabitsCount(obj.userId);
            const habit = new habit_record_1.HabitRecord(Object.assign(Object.assign({}, obj), { orderNo: currentlyAddedHabitsNo + 1, firstStatDate, lastStatUpdateDate }));
            yield habit.insert();
            res.status(201).json(habit);
        });
    }
    static update(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            const { habitId } = req.params;
            const habit = yield habit_record_1.HabitRecord.getOneById(habitId);
            if (habit && habit.userId !== req.userId) {
                return res.sendStatus(403);
            }
            if (!habit) {
                return res.sendStatus(404);
            }
            const changes = req.body;
            for (const key of Object.keys(changes)) {
                if (key === 'lastStatUpdateDate') {
                    habit.lastStatUpdateDate = new Date(new Date(changes[key]).setHours(0, 0, 0, 0));
                }
                else {
                    // @ts-ignore
                    habit[key] = changes[key];
                }
            }
            yield habit.update();
            res.json(habit);
        });
    }
    static delete(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            const { habitId } = req.params;
            const habit = yield habit_record_1.HabitRecord.getOneById(habitId);
            if (habit && habit.userId !== req.userId)
                res.sendStatus(403);
            yield habit.delete();
            res.sendStatus(200);
        });
    }
}
exports.HabitController = HabitController;
//# sourceMappingURL=habit-controller.js.map