"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserController = void 0;
const user_record_1 = require("../records/user-record");
const handleError_1 = require("../utils/handleError");
const bcrypt_1 = require("bcrypt");
const updateUserValidator_1 = require("../utils/updateUserValidator");
class UserController {
    static register(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            const userReq = req.body;
            const user = new user_record_1.UserRecord(userReq);
            yield user.insert();
            res.sendStatus(201);
        });
    }
    static delete(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            const { userId } = req.params;
            const user = yield user_record_1.UserRecord.getById(userId);
            yield user.delete();
            res.sendStatus(200);
        });
    }
    static update(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            const { userId } = req.params;
            const { password, newPassword, newEmail } = req.body;
            const user = yield user_record_1.UserRecord.getById(userId);
            if (!user)
                throw new Error('No user with that id');
            const match = yield (0, bcrypt_1.compare)(password, user.password);
            if (!match) {
                throw new handleError_1.CustomError('Wrong password.', 401);
            }
            if (newEmail) {
                if (user.email === newEmail)
                    throw new handleError_1.CustomError('You have already this email.', 400);
                yield (0, updateUserValidator_1.updateUserValidator)({ email: newEmail });
                user.email = newEmail;
                yield user.update();
            }
            else if (newPassword) {
                if (yield (0, bcrypt_1.compare)(newPassword, user.password)) {
                    throw new handleError_1.CustomError('You have already this password.');
                }
                yield (0, updateUserValidator_1.updateUserValidator)({ password: newPassword });
                user.password = newPassword;
                yield user.update(true);
            }
            else {
                throw new handleError_1.CustomError('All data are required.');
            }
            res.sendStatus(200);
        });
    }
}
exports.UserController = UserController;
//# sourceMappingURL=user-controller.js.map