"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserRecord = exports.EMAIL_REGEX = void 0;
const uuid_1 = require("uuid");
const bcrypt_1 = require("bcrypt");
const db_1 = require("../utils/db");
const handleError_1 = require("../utils/handleError");
exports.EMAIL_REGEX = /^(?:[a-z0-9!#$%&'*+/=?^_`{|}~-]+(?:\.[a-z0-9!#$%&'*+/=?^_`{|}~-]+)*|"(?:[\x01-\x08\x0b\x0c\x0e-\x1f\x21\x23-\x5b\x5d-\x7f]|\\[\x01-\x09\x0b\x0c\x0e-\x7f])*")@(?:(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?|\[(?:(?:(2(5[0-5]|[0-4][0-9])|1[0-9][0-9]|[1-9]?[0-9]))\.){3}(?:(2(5[0-5]|[0-4][0-9])|1[0-9][0-9]|[1-9]?[0-9])|[a-z0-9-]*[a-z0-9]:(?:[\x01-\x08\x0b\x0c\x0e-\x1f\x21-\x5a\x53-\x7f]|\\[\x01-\x09\x0b\x0c\x0e-\x7f])+)\])/;
class UserRecord {
    constructor(obj) {
        this.id = obj.id;
        this.email = obj.email;
        this.password = obj.password;
        this.refreshToken = obj.refreshToken;
        this.validate();
    }
    validate() {
        if (!this.email) {
            throw new handleError_1.CustomError('Email is required.');
        }
        if (!this.password) {
            throw new handleError_1.CustomError('Password is required.');
        }
        if (!exports.EMAIL_REGEX.test(this.email)) {
            throw new handleError_1.CustomError('Email is not valid. Type correct email.');
        }
        if (this.password.length < 8) {
            throw new handleError_1.CustomError('Password must be equal or longer than 8 characters.');
        }
        if (this.password.length > 100) {
            throw new handleError_1.CustomError('Password is to long. Maximum characters for password is 100.');
        }
        if (!/[A-Z]/.test(this.password)) {
            console.log(this.password);
            throw new handleError_1.CustomError('Password must contains at least one capital letter.');
        }
        if (!/[a-z]/.test(this.password)) {
            throw new handleError_1.CustomError('Password must contains at least one normal letter.');
        }
        if (!/\d/.test(this.password)) {
            throw new handleError_1.CustomError('Password must contains at least one number.');
        }
        if (!/[?!@#$%]/.test(this.password)) {
            throw new handleError_1.CustomError('Password must contains at least one special character: "?", "!", "@", "#", "$" or "%".');
        }
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                this.id = (0, uuid_1.v4)();
                this.password = yield (0, bcrypt_1.hash)(this.password, yield (0, bcrypt_1.genSalt)(10));
                yield db_1.pool.execute('INSERT INTO `users` (`id`, `email`, `password`) VALUES (:id, :email, :password)', this);
                return this.id;
            }
            catch (e) {
                console.log(e);
                throw new handleError_1.CustomError('Email is already in use.', 409);
            }
        });
    }
    update(password) {
        return __awaiter(this, void 0, void 0, function* () {
            if (password) {
                this.password = yield (0, bcrypt_1.hash)(this.password, yield (0, bcrypt_1.genSalt)(10));
                yield db_1.pool.execute('UPDATE `users` SET `email` = :email, `refreshToken` = :refreshToken, `password` = :password WHERE `id` = :id', this);
            }
            else {
                yield db_1.pool.execute('UPDATE `users` SET `email` = :email, `refreshToken` = :refreshToken WHERE `id` = :id', this);
            }
        });
    }
    delete() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute('DELETE FROM `users` WHERE `id` = :id', { id: this.id });
        });
    }
    static getByEmail(email) {
        return __awaiter(this, void 0, void 0, function* () {
            const [res] = yield db_1.pool.execute('SELECT * FROM `users` WHERE `email` = :email', { email });
            return res[0] ? new UserRecord(res[0]) : null;
        });
    }
    static getById(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [res] = yield db_1.pool.execute('SELECT * FROM `users` WHERE `id` = :id', { id });
            return res[0] ? new UserRecord(res[0]) : null;
        });
    }
}
exports.UserRecord = UserRecord;
//# sourceMappingURL=user-record.js.map