"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const habit_record_1 = require("../records/habit-record");
const db_1 = require("../utils/db");
const testUserInDb = {
    id: '1',
    email: 'test.habit@test.com',
};
const initialData = {
    name: 'running',
    orderNo: 1,
    color: '#ffffff',
    userId: testUserInDb.id,
    firstStatDate: new Date(),
    lastStatUpdateDate: new Date(),
};
let habit;
beforeAll(() => __awaiter(void 0, void 0, void 0, function* () {
    habit = new habit_record_1.HabitRecord(Object.assign({}, initialData));
}));
afterAll(() => __awaiter(void 0, void 0, void 0, function* () {
    yield db_1.pool.end();
}));
test('Not inserted habit should not have an id.', () => {
    expect(habit.id).toBeUndefined();
});
test('Inserted habit should have an id as a valid v4 uuid.', () => __awaiter(void 0, void 0, void 0, function* () {
    yield habit.insert();
    expect(habit.id).toBeDefined();
    expect(habit.id).toMatch(/^[0-9A-F]{8}-[0-9A-F]{4}-4[0-9A-F]{3}-[89AB][0-9A-F]{3}-[0-9A-F]{12}$/i);
}));
test('Fresh inserted habit should have stats length equal to 40', () => {
    expect(habit.stats.length).toEqual(40);
});
test('Getting not existing habit should return null.', () => __awaiter(void 0, void 0, void 0, function* () {
    const notExistHabit = yield habit_record_1.HabitRecord.getOneById('12121212121212121212');
    expect(notExistHabit).toBeNull();
}));
test('Creating new HabitRecord with name longer than 40 characters should throws an error.', () => __awaiter(void 0, void 0, void 0, function* () {
    habit.name = Array(41).fill('a').join();
    expect(() => new habit_record_1.HabitRecord(habit)).toThrow();
}));
test('Creating new HabitRecord with name shorter than 1 characters should throws an error.', () => __awaiter(void 0, void 0, void 0, function* () {
    habit.name = '';
    expect(() => new habit_record_1.HabitRecord(habit)).toThrow();
}));
test('Creating new HabitRecord with no stats should not throws an error.', () => __awaiter(void 0, void 0, void 0, function* () {
    expect(() => new habit_record_1.HabitRecord(Object.assign(Object.assign({}, initialData), { stats: null }))).not.toThrow();
}));
test('Creating new HabitRecord with no name should throws an error.', () => __awaiter(void 0, void 0, void 0, function* () {
    expect(() => new habit_record_1.HabitRecord(Object.assign(Object.assign({}, initialData), { name: null }))).toThrow();
}));
test('Creating new HabitRecord with no orderNo should not throws an error.', () => __awaiter(void 0, void 0, void 0, function* () {
    expect(() => new habit_record_1.HabitRecord(Object.assign(Object.assign({}, initialData), { orderNo: null }))).not.toThrow();
}));
test('Creating new HabitRecord with no color should throws an error.', () => __awaiter(void 0, void 0, void 0, function* () {
    expect(() => new habit_record_1.HabitRecord(Object.assign(Object.assign({}, initialData), { color: null }))).toThrow();
}));
test('Creating new HabitRecord with no userId should throws an error.', () => __awaiter(void 0, void 0, void 0, function* () {
    expect(() => new habit_record_1.HabitRecord(Object.assign(Object.assign({}, initialData), { userId: null }))).toThrow();
}));
test('Using delete method should delete habit.', () => __awaiter(void 0, void 0, void 0, function* () {
    yield habit.delete();
    const habitAfterDelete = yield habit_record_1.HabitRecord.getOneById('1');
    expect(habitAfterDelete).toBeNull();
}));
//# sourceMappingURL=habit.test.js.map