"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.updateUserValidator = void 0;
const handleError_1 = require("./handleError");
const user_record_1 = require("../records/user-record");
const updateUserValidator = ({ email, password }) => __awaiter(void 0, void 0, void 0, function* () {
    if (password) {
        if (password.length < 8) {
            throw new handleError_1.CustomError('Password must be equal or longer than 8 characters.');
        }
        if (password.length > 100) {
            throw new handleError_1.CustomError('Password is to long. Maximum characters for password is 100.');
        }
        if (!/[A-Z]/.test(password)) {
            throw new handleError_1.CustomError('Password must contains at least one capital letter.');
        }
        if (!/[a-z]/.test(password)) {
            throw new handleError_1.CustomError('Password must contains at least one normal letter.');
        }
        if (!/\d/.test(password)) {
            throw new handleError_1.CustomError('Password must contains at least one number.');
        }
        if (!/[?!@#$%]/.test(password)) {
            throw new handleError_1.CustomError('Password must contains at least one special character: "?", "!", "@", "#", "$" or "%".');
        }
    }
    else if (email) {
        const existsUser = yield user_record_1.UserRecord.getByEmail(email);
        if (existsUser)
            throw new handleError_1.CustomError('Email is already taken.', 409);
        if (!user_record_1.EMAIL_REGEX.test(email)) {
            throw new handleError_1.CustomError('Email is not valid. Type correct email.');
        }
    }
});
exports.updateUserValidator = updateUserValidator;
//# sourceMappingURL=updateUserValidator.js.map